# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section free
%define with_bootstrap 0

Summary:        Fast Scanner Generator
Name:           jflex
Version:        1.4.3
Release:        %mkrel 4
Epoch:          0
License:        GPLv2
URL:            http://jflex.de/
Group:          Development/Java
Source0:        http://jflex.de/%{name}-%{version}.tar.gz
Source1:        http://repo2.maven.org/maven2/de/jflex/jflex/%{version}/jflex-%{version}.pom
Source2:        jflex.script
Source3:        jflex.desktop
Source4:        jflex.png
Source5:        jflex1.script
Patch0:         jflex-build_xml.patch
Patch1:         jflex-notarget.patch
Patch2:         jflex-bootstrap.patch
Patch3:         jflex-tools_dir.patch
BuildRequires:  jpackage-utils >= 0:1.5
BuildRequires:  ant
BuildRequires:  antlr
BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  junit
BuildRequires:  java-devel
BuildRequires:  java_cup
%if !%with_bootstrap
BuildRequires:  jflex
%endif
Requires:       java
Requires:       java_cup
BuildArch:      noarch

%description
JFlex is a lexical analyzer generator (also known as scanner 
generator) for Java(tm), written in Java(tm). It is also a 
rewrite of the very useful tool JLex which was developed by 
Elliot Berk at Princeton University. As Vern Paxson states 
for his C/C++ tool flex: They do not share any code though.
JFlex is designed to work together with the LALR parser 
generator CUP by Scott Hudson, and the Java modification of 
Berkeley Yacc BYacc/J by Bob Jamison. It can also be used 
together with other parser generators like ANTLR or as a 
standalone tool. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Java

%description javadoc
%{summary}.

%prep
%setup -q

for j in $(find . -name "*.jar"); do mv $j $j.no; done
find . -name "*.class" -exec rm {} \;

%if !%with_bootstrap
  export CLASSPATH=$(build-classpath java_cup java_cup-runtime junit jflex)
  export OPT_JAR_LIST=:
  pushd src
    ant realclean
    ant jflex
  popd
%endif
%patch0 -b .sav
%patch1 -p0
%if %with_bootstrap
%patch2 -p0
%else
%patch3 -p0
%endif
 
%{__sed} -i 's/\r//' COPYRIGHT
%{__sed} -i 's|includes="JFlex/\*\*,java_cup/\*\*,skeleton|includes="JFlex/\*\*,skeleton|g' src/build.xml

%build

pushd src

%if %with_bootstrap
export CLASSPATH=$(build-classpath java_cup java_cup-runtime junit antlr)
%else
export CLASSPATH=$(build-classpath java_cup java_cup-runtime junit antlr jflex) 
%endif
export OPT_JAR_LIST=:
%ant -Djunit.jar$(build-classpath junit) compile jar

javadoc -sourcepath . -d ../api JFlex
popd

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p lib/JFlex.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; \
   do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir} && ln -sf jflex.jar JFlex.jar)
   


# poms
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 %{SOURCE1} \
    %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom jflex.jar

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} 

# docs
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p doc/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p COPYRIGHT $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -pm 755 %{SOURCE5} %{buildroot}%{_bindir}/jflex

mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install %{SOURCE3} --mode=644 --dir=%{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/jflex.desktop

mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m  644 %{SOURCE4} %{buildroot}%{_datadir}/pixmaps/jflex.png
for png in 32 48 64; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${png}x${png}/apps/
  convert -resize ${png}x${png} %{SOURCE4} \
    %{buildroot}%{_datadir}/icons/hicolor/${png}x${png}/apps/jflex.png
done

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%{_bindir}/update-desktop-database -q %{_datadir}/applications
touch --no-create %{_datadir}/icons/hicolor

%postun
%update_maven_depmap
if [ $1 -eq 0 ]; then
  touch --no-create %{_datadir}/icons/hicolor
  %{_bindir}/gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
fi

%posttrans
%{_bindir}/gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :

%files
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/jflex
%{_datadir}/applications/jflex.desktop
%{_datadir}/icons/hicolor/*/apps/jflex.png
%{_datadir}/pixmaps/jflex.png
%doc %{_docdir}/%{name}-%{version}
%{_javadir}/*.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/%{name}-%{version}
%doc %{_javadocdir}/%{name}



%changelog

* Thu Nov 03 2011 dmorgan <dmorgan> 0:1.4.3-4.mga2
+ Revision: 162423
- Fix BuildRequires

  + gil <gil>
    - added new script
    - edit spec file
    - used ju fedora new macro

* Mon Jan 17 2011 dmorgan <dmorgan> 0:1.4.3-1.mga1
+ Revision: 21638
- Add missing patch
- Add missing file
- New version
  Sync with fedora

* Mon Jan 17 2011 dmorgan <dmorgan> 0:1.4.1-15.mga1
+ Revision: 21626
- Enable bootstrap
- imported package jflex


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.4.1-15mdv2011.0
+ Revision: 606081
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.4.1-14mdv2010.1
+ Revision: 523084
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.4.1-13mdv2010.0
+ Revision: 425460
- rebuild

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 0:1.4.1-12mdv2009.0
+ Revision: 221710
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:1.4.1-11mdv2008.1
+ Revision: 120941
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.4.1-10mdv2008.0
+ Revision: 87433
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sat Sep 08 2007 Pascal Terjan <pterjan@mandriva.org> 0:1.4.1-9mdv2008.0
+ Revision: 82536
- update to new version


* Wed Nov 08 2006 David Walluck <walluck@mandriva.org>
+ 2006-11-08 04:53:36 (78038)
- BuildRequires: jflex for non-bootstrap
- disable bootstrap

* Tue Nov 07 2006 David Walluck <walluck@mandriva.org> 1.4.1-6mdv2007.1
+ 2006-11-07 12:12:56 (77050)
- fix some (Build)Requires
- enable bootstrap
- Import jflex

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-4mdv2007.0
- fix build by removing included java_cup sources

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-3mdv2007.0
- don't clean generated files before build (fails)
- add byaccj url fix from Debian
- remove jflex dir from $RPM_BUILD_DIR

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-2mdv2007.0
- clean build environment

* Sat Sep 09 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-1mdv2007.0
- release

